@@ -5,7 +5,7 @@ from sys import _getframe
 import os
 
 
-def frameOutOfContext():
+def frame_out_of_context():
     this_frame = frame = _getframe(1)
     while folder() in frame.f_code.co_filename:
         frame = frame.f_back
@@ -22,3 +22,8 @@ def format_called(attr, args, kargs):
     return "%s(%s)"%( attr, parameters)
 
 
+
+def _reindent(text, space_with=4):
+	lines = text.split("\n")
+	lines_indented = [" "*space_with+line for line in lines]
+	return '\n'.join(lines_indented)
\ No newline at end of file
