@@ -2,16 +2,15 @@
 
 from inspect import getframeinfo 
 from sys import _getframe as getframe 
-from _testdouble import _TestDouble 
+from _testdouble import _ProxyToAlias
 from dependencyinjection import DependencyInjection
 from traceroute import TraceRoute
-from ludibrio.helpers import format_called
-
+from ludibrio.helpers import format_called, _reindent
 STOPRECORD = False
 RECORDING = True
 
 
-class Mock(_TestDouble):
+class Mock(_ProxyToAlias):
     """Mocks are what we are talking about here:
     objects pre-programmed with expectations which form a
     specification of the calls they are expected to receive.
@@ -44,7 +43,7 @@ class Mock(_TestDouble):
             return self._expectancy_recorded(property, args, kargs)
 
     def __exit__(self, type, value, traceback):
-        self.__dependency_injection__.restoure_import()
+        self.__dependency_injection__.restore_import()
         self.__recording__ = STOPRECORD
 
     def __setattr__(self, attr, value):
@@ -58,7 +57,7 @@ class Mock(_TestDouble):
 
     def __rshift__(self, response):
             self.__expectation__[-1].set_response(response)
-    __lshift__ = __rshift__ 
+    gives = __lshift__ = __rshift__ 
 
     def _expectancy_recorded(self, attr, args=[], kargs={}):
         try:
@@ -67,17 +66,20 @@ class Mock(_TestDouble):
             else:
                 return self._call_mocked_unordered(attr, args, kargs)
         except (CallExpectation, IndexError):
-            raise MockExpectationError(self._unexpected_call_msg(attr, args, kargs))
+            self.__dependency_injection__.restore_object()
+            raise MockExpected(self._unexpected_call_msg(attr, args, kargs))
 
     def _unexpected_call_msg(self, attr, args, kargs):
-        return ("Mock Object received unexpected call:%s\n"
-                "Expected:\n"
-                "%s\n"
+        return ("\n"
+				"%s\n"
                 "Got:\n"
-                "%s") % (
+                "%s\n"
+				"Mock Object received unexpected call:%s"
+                ) % (
+                    _reindent(self.__traceroute_expected__.stack_code(), 2),
+                    self.__traceroute__.stack_trace(),
                     format_called(attr, args, kargs),
-                    self.__traceroute_expected__.stack_code(),
-                    self.__traceroute__.stack_trace())
+					)
 
     def _is_ordered(self):
         return self.__kargs__.get('ordered', True)
@@ -97,13 +99,13 @@ class Mock(_TestDouble):
         return self._property_called('__getattribute__',[x])
 
     def validate(self):
-        self.__dependency_injection__.restoure_object()
+        self.__dependency_injection__.restore_object()
         if self.__expectation__:
             raise MockExpectationError(
                     self._call_waiting_msg())
 
     def __del__(self):
-        self.__dependency_injection__.restoure_object()
+        self.__dependency_injection__.restore_object()
         if self.__expectation__:
             print  self._call_waiting_msg()
     
@@ -147,5 +149,8 @@ class MockedCall(object):
 class MockExpectationError(AssertionError):
     """Extends AssertionError for unittest compatibility"""
 
+class MockExpected(AssertionError):
+    """Extends AssertionError for unittest compatibility"""
+
 class CallExpectation(AssertionError):
     """Extends AssertionError for unittest compatibility"""
