@@ -2,7 +2,7 @@
 
 from inspect import getframeinfo
 from sys import _getframe as getframe
-from _testdouble import _TestDouble
+from _testdouble import _ProxyToAlias
 from dependencyinjection import DependencyInjection
 from traceroute import TraceRoute
 from ludibrio.helpers import format_called
@@ -11,7 +11,7 @@ STOPRECORD = False
 RECORDING = True
 
 
-class Stub(_TestDouble):
+class Stub(_ProxyToAlias):
     """Stubs provides canned answers to calls made during the test.
     """
     __expectation__= [] # [(attribute, args, kargs),]
@@ -46,7 +46,7 @@ class Stub(_TestDouble):
             return self._expectation_value(property, args, kargs)
 
     def __exit__(self, type, value, traceback):
-        self.__dependency_injection__.restoure_import()
+        self.__dependency_injection__.restore_import()
         self.__recording__ = STOPRECORD
 
     def __setattr__(self, attr, value):
@@ -55,27 +55,31 @@ class Stub(_TestDouble):
         else:
             self._property_called('__setattr__', args=[attr, value])
 
-    def _new_expectation(self, attr):
-        self.__expectation__.append(attr)
+    def _new_expectation(self, expectation):
+        self.__expectation__.append(expectation)
 
     def __rshift__(self, response):
             self.__expectation__[-1][3] = response
-    __lshift__ = __rshift__
+    gives = __lshift__ = __rshift__
 
     def _expectation_value(self, attr, args=[], kargs={}):
         for position, (attr_expectation, args_expectation, kargs_expectation, response) in enumerate(self.__expectation__):
             if (attr_expectation, args_expectation, kargs_expectation) == (attr, args, kargs):
                 self._to_the_end(position)
-                return response
+                if isinstance(response, Exception):
+	                raise response
+                else:
+	                return response 
         if self._has_proxy():
             return self._proxy(attr, args, kargs)
         self._attribute_expectation(attr, args, kargs)
 
     def _attribute_expectation(self, attr, args, kargs):
         raise AttributeError(
-            "Stub Object received unexpected call. %s\n%s"%(
+            "\n%s\nStub Object received unexpected call: %s"%(
+                    self.__traceroute__.stack_trace(),
                     self._format_called(attr, args, kargs),
-                    self.__traceroute__.stack_trace()))
+					))
 
     def _proxy(self, attr, args, kargs):
         return getattr(self.__kargs__.get('proxy'), attr)(*args, **kargs)
@@ -96,7 +100,7 @@ class Stub(_TestDouble):
         return self._property_called('__getattribute__', (x,), response=self)
     
     def __del__(self):
-        self.__dependency_injection__.restoure_object()
+        self.__dependency_injection__.restore_object()
     
-    def restoure_import(self):
-        self.__dependency_injection__.restoure_object()
+    def restore_import(self):
+        self.__dependency_injection__.restore_object()
